package xhttp3.internal.framed;

import java.util.Arrays;

public final class Settings {
   static final int DEFAULT_INITIAL_WINDOW_SIZE = 65536;
   static final int FLAG_CLEAR_PREVIOUSLY_PERSISTED_SETTINGS = 1;
   static final int PERSIST_VALUE = 1;
   static final int PERSISTED = 2;
   static final int UPLOAD_BANDWIDTH = 1;
   static final int HEADER_TABLE_SIZE = 1;
   static final int DOWNLOAD_BANDWIDTH = 2;
   static final int ENABLE_PUSH = 2;
   static final int ROUND_TRIP_TIME = 3;
   static final int MAX_CONCURRENT_STREAMS = 4;
   static final int CURRENT_CWND = 5;
   static final int MAX_FRAME_SIZE = 5;
   static final int DOWNLOAD_RETRANS_RATE = 6;
   static final int MAX_HEADER_LIST_SIZE = 6;
   static final int INITIAL_WINDOW_SIZE = 7;
   static final int CLIENT_CERTIFICATE_VECTOR_SIZE = 8;
   static final int FLOW_CONTROL_OPTIONS = 10;
   static final int COUNT = 10;
   static final int FLOW_CONTROL_OPTIONS_DISABLED = 1;
   private int set;
   private int persistValue;
   private int persisted;
   private final int[] values = new int[10];

   void clear() {
      this.persisted = 0;
      this.persistValue = 0;
      this.set = 0;
      Arrays.fill(this.values, 0);
   }

   Settings set(int id, int idFlags, int value) {
      int[] var4;
      if (id >= (var4 = this.values).length) {
         return this;
      } else {
         int var5 = 1 << id;
         this.set |= var5;
         if ((idFlags & 1) != 0) {
            this.persistValue |= var5;
         } else {
            this.persistValue &= ~var5;
         }

         if ((idFlags & 2) != 0) {
            this.persisted |= var5;
         } else {
            this.persisted &= ~var5;
         }

         var4[id] = value;
         return this;
      }
   }

   boolean isSet(int id) {
      Settings var10000 = this;
      int var2 = 1 << id;
      return (var10000.set & var2) != 0;
   }

   int get(int id) {
      return this.values[id];
   }

   int flags(int id) {
      int var2 = 0;
      if (this.isPersisted(id)) {
         var2 = 2;
      }

      if (this.persistValue(id)) {
         var2 |= 1;
      }

      return var2;
   }

   int size() {
      return Integer.bitCount(this.set);
   }

   int getUploadBandwidth(int defaultValue) {
      if ((this.set & 2) != 0) {
         defaultValue = this.values[1];
      }

      return defaultValue;
   }

   int getHeaderTableSize() {
      return (this.set & 2) != 0 ? this.values[1] : -1;
   }

   int getDownloadBandwidth(int defaultValue) {
      if ((this.set & 4) != 0) {
         defaultValue = this.values[2];
      }

      return defaultValue;
   }

   boolean getEnablePush(boolean defaultValue) {
      return ((this.set & 4) != 0 ? this.values[2] : (defaultValue ? 1 : 0)) == 1;
   }

   int getRoundTripTime(int defaultValue) {
      if ((this.set & 8) != 0) {
         defaultValue = this.values[3];
      }

      return defaultValue;
   }

   int getMaxConcurrentStreams(int defaultValue) {
      if ((this.set & 16) != 0) {
         defaultValue = this.values[4];
      }

      return defaultValue;
   }

   int getCurrentCwnd(int defaultValue) {
      if ((this.set & 32) != 0) {
         defaultValue = this.values[5];
      }

      return defaultValue;
   }

   int getMaxFrameSize(int defaultValue) {
      if ((this.set & 32) != 0) {
         defaultValue = this.values[5];
      }

      return defaultValue;
   }

   int getDownloadRetransRate(int defaultValue) {
      if ((this.set & 64) != 0) {
         defaultValue = this.values[6];
      }

      return defaultValue;
   }

   int getMaxHeaderListSize(int defaultValue) {
      if ((this.set & 64) != 0) {
         defaultValue = this.values[6];
      }

      return defaultValue;
   }

   int getInitialWindowSize(int defaultValue) {
      if ((this.set & 128) != 0) {
         defaultValue = this.values[7];
      }

      return defaultValue;
   }

   int getClientCertificateVectorSize(int defaultValue) {
      if ((this.set & 256) != 0) {
         defaultValue = this.values[8];
      }

      return defaultValue;
   }

   boolean isFlowControlDisabled() {
      return (((this.set & 1024) != 0 ? this.values[10] : 0) & 1) != 0;
   }

   boolean persistValue(int id) {
      Settings var10000 = this;
      int var2 = 1 << id;
      return (var10000.persistValue & var2) != 0;
   }

   boolean isPersisted(int id) {
      Settings var10000 = this;
      int var2 = 1 << id;
      return (var10000.persisted & var2) != 0;
   }

   void merge(Settings other) {
      for(int var2 = 0; var2 < 10; ++var2) {
         if (other.isSet(var2)) {
            int var3 = other.flags(var2);
            int var4 = other.get(var2);
            this.set(var2, var3, var4);
         }
      }

   }
}
